/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef SENDS_DUMP_TRANS_HH
#define SENDS_DUMP_TRANS_HH

#include "seda_stage.hh"

namespace sends {

    /**  Dump_trans is a SEDA stage thatreleases the input transaction and
      *  returns the transaction object to the free transaction pool.
      *  @brief Trash a transaction.
      *  @author John Zweizig
      *  @version 1.0; Last modified January 23, 2008
      *  @ingroup sends_stage
      */
    class dump_trans : public seda_stage {
    public:
	/**  Construct a transaction dump stage.
	  *  @brief Constructor
	  *  @param nThread Number of thread in the pool.
	  *  @param nTrans  Number of transactions to accept in the input queue.
	  */
	dump_trans(int nThread, int nTrans);

	/**  Perform the stage processing. The input transaction is relased
	  *  and returned to the transaction pool.
	  *  @brief Stage filter.
	  *  @param trans Transaction to be processed.
	  */
	void filter(transaction* trans);

	/**  Return a constant pointer to a null-terminated character vector 
	  *  with the stage name.
	  *  @brief Stage name.
	  *  @return Pointer to the stage name string.
	  */
	const char* stage_name(void) const;
    private:
    };
}

#endif // !defined(SENDS_DUMP_TRANS_HH)
