/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef SENDS_FILE_DRIVER_HH
#define SENDS_FILE_DRIVER_HH

#include "frame_driver.hh"

namespace sends {
    class loc_list;

    /**  NDS2 input driver for frame files on a posix file system.
      *  \brief Frame file input driver.
      *  \ingroup sends_drive
      *  \version 1.1; last modified November 27, 2008.
      *  \author John Zweizig
      */
    class file_driver : public frame_driver {
    public:

	/**  Construct a posix file-system driver.
	  *  \brief Constructor
	  */
	file_driver(void);

	/**  Destroy a posix file-system driver.
	  *  \brief Destructor
	  */
	~file_driver(void);

	/**  Get the driver specific name ("file").
	  *  \brief get the driver name.
	  *  \return driver name "file".
	  */
	std::string name(void) const;

	/**  Read data from the specified path for the specified times. 
	  *  Channel names and segments they are to be read into are passed
	  *  as a list.
	  *  \brief Read channel ldata into segments. 
	  *  \param type  Source frame list.
	  *  \param path  Source descriptor path field.
	  *  \param start Start gps time of data to be read.
	  *  \param end   End gps of data to be read.
	  *  \param lst   List of channels and segment IDs.
	  *  \return Result code. 0 if all requested data were read,
	  *          otherwise -1.
	  */
	virtual int read_data(const loc_list& type, gps_type start, 
			      gps_type dt, const channel_vect& lst);

    };

    //==================================  Inline methods
    inline std::string 
    file_driver::name(void) const {
	return "file";
    }

}  // namspace sends

#endif   // !defined(SENDS_FILE_DRIVER_HH)
