/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef GPS_DATE_HH
#define GPS_DATE_HH

/**  The %gpsdate class generates a "GPS date" from a gps time. The GPS date
  *  calculates the year, day in year, hour, minute and second ignoring 
  *  leap seconds. As a simplification, only simple leap-years are calculated.
  *
  *  \brief Calculate nominal date from a GPS time ignoring leap seconds.
  *  \author John Zweizig (john.zweizig@ligo.org)
  *  \version $Id$
  */
class gps_date {
public:
    /**  Construct a gps_date for a specified GPS time.
      *  \brief Contruct %gps_date;
      *  \param gps GPS time.
      */
    gps_date(long gps);

    /**  Destroy a gps time.
      *  \brief Destructor.
      */
    ~gps_date(void);

    /**  Return the GPS year for deconstructed time.
      *  \Brief GPS year.
      *  \return GPS year as an integer (\e e.g. 2011).
      */
    int year(void) const;

    /**  Number of the day in the year in the range of 0-364 (365 for leap 
      *  years). January first is always day zero. The start of the GPS day 
      *  is offset from the UTC day by the number of leap seconds in effect.
      *  \brief Number of day in gps year.
      *  \return Number of day in gps year.
      */
    int day_in_year(void) const;

    /**  Hour number in the range 0-23. The start of the GPS hour is offset 
      *  from the UTC hour by the number of leap seconds in effect.
      *  \brief Number of gps hourr.
      *  \return Hour within the day.
      */
    int hour(void) const;
private:
    int mYear;
    int mDayInYear;
    int mHour;
};

//======================================  Inline accessors
inline int 
gps_date::year(void) const {
    return mYear;
}

inline int
gps_date::day_in_year(void) const {
    return mDayInYear;
}

inline int
gps_date::hour(void) const {
    return mHour;
}

#endif // !defined(GPS_DATE_HH)
