/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef SENDS_POOL_MGR
#define SENDS_POOL_MGR

namespace sends {

    class buffer;
    class buffer_pool;

    /**  Abstract class to manage pools of buffers of different lengths.
      *  @brief Buffer pool manager API.
      *  @author John Zweizig
      *  @version 1.0;Last modified February 12, 2008
      *  @ingroup sends_base
      */
    class pool_mgr {
    public:
	/**  Type of data used to select a buffer class.
	  */
	typedef unsigned long select_type;

	/**  Type of data use to represent a buffer class.
	  */
	typedef unsigned long bufclass_type;

    public:
	/**  Construct a pool manager.
	  *  @brief constructor.
	  */
	pool_mgr(void) {}

	/**  Construct a pool manager.
	  *  @brief constructor.
	  */
	virtual ~pool_mgr(void) {}

	/**  Decide on a buffer class based on the selection code.
	  *  @brief Chose a buffer class.
	  *  @param selid Selection code.
	  *  @return Buffer class for selid.
	  */
	virtual bufclass_type get_buffer_class(select_type selid) const=0;

	/**  Allocate a buffer of the specified class.
	  *  @brief Chose a buffer class.
	  *  @param selclass buffer class code.
	  *  @return Pointer to requested buffer.
	  */
	virtual buffer* get_buffer(select_type selclass)=0;	

	/**  Allocate a buffer of the specified class without waiting.
	  *  @brief Chose a buffer class.
	  *  @param selclass buffer class code.
	  *  @return Pointer to requested buffer.
	  */
	virtual buffer* get_buffer_now(select_type selclass)=0;	
    };

}  // namespace sends

#endif // !defined(SENDS_POOL_MGR)
