/* -*- mode: c++; c-basic-offset: 4; -*- */
#ifndef SENDS_SYSEXCEPT_HH
#define SENDS_SYSEXCEPT_HH

#include <stdexcept>
#include <string>
#include <cstring>
#include <errno.h>

namespace sends {

    /**  The nds_system_error class is based on the standard runtime_error 
      *  exception class and is used to indicate that an exception was 
      *  thrown when a system function returned an error. The system
      *  error text is added to the text specified in the constructor.
      *  \brief System error exception class.
      *  \author John Zweizig
      *  \version 1.0
      */
    class nds_system_error : public std::runtime_error {
    public:
	/**  Construct a system error exception. THe syste error code
	  *  is  taken from errno.
	  *  \brief Construct system error exception
	  *  \param msg Error location string.
	  */
	nds_system_error(const std::string& msg) 
	    : std::runtime_error(msg + ": " + strerror(errno))
	{}

	/**  Construct a system error exception. The system error code
	  *  is  passed as an argument.
	  *  \brief Construct system error exception
	  *  \param msg Error location string.
	  *  \param err System error code.
	  */
	nds_system_error(const std::string& msg, int err) 
	    : std::runtime_error(msg + ": " + strerror(err))
	{}
    };

}

#endif // !defined(SENDS_SYSEXCEPT_HH)
