/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef SENDS_UNKNOWN_CHANNEL_MESSAGE_HH
#define SENDS_UNKNOWN_CHANNEL_MESSAGE_HH
#include <string>
#include "chan_type.hh"
#include "epoch.hh"

namespace sends {

   /**  Channel matching errors.
    */
   enum ucm_enum {
      ucm_Unknown,
      ucm_BadType,
      ucm_SimData,
      ucm_BadRate,
      ucm_BadEpoch,
      ucm_BadTime
   };
    
   /**  The unknown_channel_class keeps track of the message that best  
    *  informs the user at what point the channel was rejected. The 
    *  possible messages are:
    *  * Unknown channel: %s - The specified channel name doesn't exist
    *  * Channel %s not found with type % - The channel with specified name
    *    and type is not found.
    *  * Channel %s,%s not found at time %s - Channel not found at specified 
    *    time
    */
   class unknown_channel_message {
   public:
      unknown_channel_message(void) : _msgid(ucm_Unknown) {}
      ~unknown_channel_message(void) {}
      void set(ucm_enum id) {if (id > _msgid) _msgid = id;}
      std::string put_message(const std::string&, chan_type t,
			      const epoch& epik) const; 
   private:
      ucm_enum _msgid;
   };

}  //namespace sends

#endif // !defined(SENDS_UNKNOWN_CHANNEL_MESSAGE_HH)
